@@ -34,8 +34,8 @@ predict.bn.fit.gnode = function(object, data, ..., debug = FALSE) {
 
   # check the data are there.
   check.data(data)
-  # a valid node is needed.
-  check.nodes(nodes = target, graph = nodes, max.nodes = 1)
+  # check the fitted node.
+  check.fit.node.vs.data(object, data)
   # warn about unused arguments.
   check.unused.args(list(...), character(0))
 
@@ -43,6 +43,7 @@ predict.bn.fit.gnode = function(object, data, ..., debug = FALSE) {
   dummy = vector(length(nodes), mode = "list")
   names(dummy) = nodes
   dummy[[target]] = object
+
   # compute the predicted values.
   gaussian.prediction(node = target, fitted = dummy, data = data, debug = debug)
 
@@ -51,20 +52,21 @@ predict.bn.fit.gnode = function(object, data, ..., debug = FALSE) {
 # estimate the predicted values for a discrete node.
 predict.bn.fit.dnode = function(object, data, ..., debug = FALSE) {
 
-  # check the data are there.
-  check.data(data)
-  # a valid node is needed.
-  check.nodes(nodes = target, graph = nodes, max.nodes = 1)
-  # warn about unused arguments.
-  check.unused.args(list(...), character(0))
-
   nodes = names(data)
   target = object$node
 
+  # check the data are there.
+  check.data(data)
+  # check the fitted node.
+  check.fit.node.vs.data(object, data)
+  # warn about unused arguments.
+  check.unused.args(list(...), character(0))
+
   # create a dummy bn.fit object to pass to discrete.prediction().
   dummy = vector(length(nodes), mode = "list")
   names(dummy) = nodes
   dummy[[target]] = object
+
   # compute the predicted values.
   discrete.prediction(node = target, fitted = dummy, data = data, debug = debug)
 
@@ -93,6 +95,7 @@ predict.bn.naive = function(object, data, prior, ..., debug = FALSE) {
   training = root.leaf.nodes(fitted, leaf = FALSE)
   # check the prior distribution.
   prior = check.prior(prior, data[, training])
+
   # compute the predicted values.
   naive.classifier(training = training, fitted = fitted, data = data,
     prior = prior, debug = debug)
