@@ -14,46 +14,55 @@ per.node.score = function(network, data, score, nodes, extra.args,
 
   if (score == "k2") {
 
-   res = sapply(nodes, dirichlet.node, x = network, data = data,
-           debug = debug)
+   res = vapply(nodes, dirichlet.node, x = network, data = data,
+           debug = debug, FUN.VALUE = template.numeric)
 
   }#THEN
   else if (score == "bde") {
 
-   res = sapply(nodes, dirichlet.node, x = network,
-           imaginary.sample.size = extra.args$iss, data = data,
-           debug = debug)
+   res = vapply(nodes, dirichlet.node, x = network,
+           imaginary.sample.size = extra.args$iss, 
+           experimental = NULL, data = data,
+           debug = debug, FUN.VALUE = template.numeric)
+
+  }#THEN
+  else if (score == "mbde") {
+
+   res = vapply(nodes, dirichlet.node, x = network,
+           imaginary.sample.size = extra.args$iss, 
+           experimental = extra.args$exp, data = data,
+           debug = debug, FUN.VALUE = template.numeric)
 
   }#THEN
   else if (score == "loglik") {
 
-    res = sapply(nodes, loglik.node, x = network, data = data,
-            debug = debug)
+    res = vapply(nodes, loglik.node, x = network, data = data,
+            debug = debug, FUN.VALUE = template.numeric)
 
   }#THEN
   else if (score %in% c("aic", "bic")) {
 
-    res = sapply(nodes, aic.node, x = network, data = data,
-            k = extra.args$k, debug = debug)
+    res = vapply(nodes, aic.node, x = network, data = data,
+            k = extra.args$k, debug = debug, FUN.VALUE = template.numeric)
 
   }#THEN
   else if (score == "bge") {
 
-    res = sapply(nodes, bge.node, x = network, phi = extra.args$phi,
-            data = data, imaginary.sample.size = extra.args$iss,
-            debug = debug)
+    res = vapply(nodes, bge.node, x = network, phi = extra.args$phi,
+            data = data, iss = extra.args$iss, debug = debug,
+            FUN.VALUE = template.numeric)
 
   }#THEN
   else if (score == "loglik-g") {
 
-    res = sapply(nodes, gloglik.node, x = network, data = data,
-            debug = debug)
+    res = vapply(nodes, gloglik.node, x = network, data = data,
+            debug = debug, FUN.VALUE = template.numeric)
 
   }#THEN
   else if (score %in% c("aic-g", "bic-g")) {
 
-    res = sapply(nodes, aic.gauss.node, x = network, data = data,
-            k = extra.args$k, debug = debug)
+    res = vapply(nodes, aic.gauss.node, x = network, data = data,
+            k = extra.args$k, debug = debug, FUN.VALUE = template.numeric)
 
   }#THEN
 
@@ -189,7 +198,8 @@ aic.node = function(node, x, data, k = 1, debug = FALSE) {
 }#AIC.NODE
 
 # compute the dirichlet posterior density of a node.
-dirichlet.node = function(node, x, data, imaginary.sample.size = NULL, debug = FALSE) {
+dirichlet.node = function(node, x, data, imaginary.sample.size = NULL,
+    experimental = NULL, debug = FALSE) {
 
   if (debug) {
 
@@ -202,14 +212,15 @@ dirichlet.node = function(node, x, data, imaginary.sample.size = NULL, debug = F
   node.parents = x$nodes[[node]]$parents
   # extract the node's column from the data frame.
   datax = minimal.data.frame.column(data, node)
+  # extract the list of eperimental data.
+  exp.data = minimal.data.frame.column(experimental, node)
 
   if (length(node.parents) == 0) {
 
     dirichlet = .Call("dpost",
        x = datax,
-       lx = nlevels(datax),
-       length = nrow(data),
        iss = imaginary.sample.size,
+       exp = exp.data,
        PACKAGE = "bnlearn")
 
   }#THEN
@@ -226,10 +237,8 @@ dirichlet.node = function(node, x, data, imaginary.sample.size = NULL, debug = F
     dirichlet = .Call("cdpost",
        x = datax,
        y = config,
-       lx = nlevels(datax),
-       ly = nlevels(config),
-       length = nrow(data),
        iss = imaginary.sample.size,
+       exp = exp.data,
        nparams = node.params,
        PACKAGE = "bnlearn")
 
@@ -243,21 +252,19 @@ dirichlet.node = function(node, x, data, imaginary.sample.size = NULL, debug = F
 }#DIRICHLET.NODE
 
 # compute the posterior density of a gaussian node.
-# Reverse-engineered from the deal package, with copyright:
-# Copyright (C) 2002  Susanne Gammelgaard Bøttcher, Claus Dethlefsen
-# Original code licenced under GPLv2 or later version.
-bge.node = function(node, x, data, imaginary.sample.size, phi = "heckerman",
-    debug = FALSE) {
+bge.node = function(node, x, data, iss, phi = "heckerman", debug = FALSE) {
 
   # cache the sample size.
   n = nrow(data)
   # cache the phi multiplier.
   if (phi == "bottcher")
-    phi.coef = (n - 1) / n * (imaginary.sample.size - 1)
+    phi.coef = (n - 1) / n * (iss - 1)
   else if (phi == "heckerman")
-    phi.coef = (n - 1) / n * (imaginary.sample.size) / (imaginary.sample.size + 1) * (imaginary.sample.size - 2)
+    phi.coef = (n - 1) / n * (iss) / (iss + 1) * (iss - 2)
   # initialize the result.
   result = 0
+  # get the parents of the node.
+  node.parents = x$nodes[[node]]$parents
 
   if (debug) {
 
@@ -266,73 +273,30 @@ bge.node = function(node, x, data, imaginary.sample.size, phi = "heckerman",
 
   }#THEN
 
-  if (length(x$nodes[[node]]$parents) == 0) {
+  if (length(node.parents) == 0) {
 
-    # Posterior for continuous node with no parents
-    result = .C("postc0",
-       mu = as.double(mean(data[, node])),
-       tau = as.double(imaginary.sample.size),
-       rho = as.double(imaginary.sample.size),
-       phi = as.double(var(data[, node]) * phi.coef),
-       loglik = as.double(result),
-       y = as.double(data[, node]),
-       n = as.integer(n),
-       PACKAGE = "bnlearn")$loglik
+     result = .Call("wpost",
+                    x = minimal.data.frame.column(data, node),
+                    imaginary = iss,
+                    phi.coef = phi.coef,
+                    PACKAGE = "bnlearn")
 
   }#THEN
   else {
 
-    # Posterior for continuous node with continuous parents
-    node.parents = x$nodes[[node]]$parents
-    n.parents = length(node.parents)
-
-    tau.build = function(A, mu, nu, rho, phi) {
-
-      B = A
-
-      A = setdiff(1:ncol(phi),B)
-      if (length(A) < 1) A = TRUE
-
-      rho.BlA = rho + length(A)
-      phi.AA.inv = solve(phi[A,A])
-      phi.tmp = phi[B,A] %*% phi.AA.inv
-      phi.BlA = phi[B,B] - phi.tmp%*%phi[A,B]
-      mu.BlA  = c(mu[B] - phi.tmp%*%mu[A], phi.tmp)
-      tau.BlA.inv.11 = 1/nu + t(mu[A])%*%phi.AA.inv%*%mu[A]
-      tau.BlA.inv.22 = phi.AA.inv
-      tau.BlA.inv.12 = -t(mu[A] %*% phi.AA.inv)
-
-      tau.inv = rbind(cbind(tau.BlA.inv.11, t(tau.BlA.inv.12)),
-                       cbind(tau.BlA.inv.12, tau.BlA.inv.22))
-
-      solve(tau.inv)
-
-    }#TAU.BUILD
-
-    tau = tau.build(A = which(node.parents %in% names(x$nodes)),
-            mu = mean(data[, node.parents]),
-            nu = imaginary.sample.size,
-            rho = imaginary.sample.size,
-            phi = var(data[, node.parents, drop = FALSE]) * phi.coef)
-
-    result = .C("postc",
-        mu = as.double(c(mean(data[, node]), rep(0, n.parents))),
-        tau = as.double(t(tau)),
-        rho = as.double(imaginary.sample.size + n.parents),
-        phi = as.double(var(data[, node]) * phi.coef),
-        loglik = as.double(result),
-        y = as.double(data[, node]),
-        z = as.double(t(cbind("1" = rep(1, n), data[, node.parents]))),
-        n = as.integer(n),
-        d = as.integer(n.parents + 1),
-        PACKAGE = "bnlearn")$loglik
+    result = .Call("cwpost",
+                   x = minimal.data.frame.column(data, node),
+                   z = minimal.data.frame.column(data, node.parents, drop = FALSE),
+                   imaginary = iss,
+                   phi.coef = phi.coef,
+                   PACKAGE = "bnlearn")
 
   }#THEN
 
   if (debug)
     cat("  > posterior density is", result, ".\n")
 
-result
+  return(result)
 
 }#BGE.NODE
 
